==> illuminaMousev2.db_1.1.3.tar.gz: illuminaMousev2.db/man/illuminaMousev2_dbconn.Rd <==
\name{illuminaMousev2_dbconn}

\alias{illuminaMousev2_dbconn}
\alias{illuminaMousev2_dbfile}
\alias{illuminaMousev2_dbschema}
\alias{illuminaMousev2_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  illuminaMousev2_dbconn()
  illuminaMousev2_dbfile()
  illuminaMousev2_dbschema(file="", show.indices=FALSE)
  illuminaMousev2_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{illuminaMousev2_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{illuminaMousev2_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{illuminaMousev2_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{illuminaMousev2_dbschema} prints the schema definition of the
  package annotation DB.

  \code{illuminaMousev2_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{illuminaMousev2_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{illuminaMousev2_dbfile}: a character string with the path to the
  package annotation DB.

  \code{illuminaMousev2_dbschema}: none (invisible \code{NULL}).

  \code{illuminaMousev2_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(illuminaMousev2_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by illuminaMousev2_dbconn() was created with:
  dbConnect(SQLite(), dbname=illuminaMousev2_dbfile(), cache_size=64000, synchronous=0)

  illuminaMousev2_dbschema()

  illuminaMousev2_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> illuminaMousev2.db_1.16.1.tar.gz: illuminaMousev2.db/man/illuminaMousev2_dbconn.Rd <==

\name{illuminaMousev2_dbconn}

\alias{illuminaMousev2_dbconn}
\alias{illuminaMousev2_dbfile}
\alias{illuminaMousev2_dbschema}
\alias{illuminaMousev2_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  illuminaMousev2_dbconn()
  illuminaMousev2_dbfile()
  illuminaMousev2_dbschema(file="", show.indices=FALSE)
  illuminaMousev2_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{illuminaMousev2_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{illuminaMousev2_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{illuminaMousev2_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{illuminaMousev2_dbschema} prints the schema definition of the
  package annotation DB.

  \code{illuminaMousev2_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{illuminaMousev2_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{illuminaMousev2_dbfile}: a character string with the path to the
  package annotation DB.

  \code{illuminaMousev2_dbschema}: none (invisible \code{NULL}).

  \code{illuminaMousev2_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(illuminaMousev2_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by illuminaMousev2_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=illuminaMousev2_dbfile(), cache_size=64000,
  synchronous=0)

  illuminaMousev2_dbschema()

  illuminaMousev2_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
